@@ -6,14 +6,14 @@ from typing import Any, Dict, Final, Iterable, Optional, Tuple, Union
 
 import attr
 
-from .api_types import (APIResponse, BaseTelegram, BotCommand, Chat,
-                        ChatInviteLink, ChatMember, ChatPermissions, File,
-                        GameHighScore, InlineKeyboardMarkup, InlineQueryResult,
-                        InputFile, InputMedia, InputMediaAudio,
-                        InputMediaDocument, InputMediaPhoto, InputMediaVideo,
-                        LabeledPrice, MaskPosition, Message, MessageEntity,
-                        MessageId, PassportElementError, Poll, ReplyMarkup,
-                        ShippingOption, StickerSet, Update, User,
+from .api_types import (APIResponse, BaseTelegram, BotCommand, BotCommandScope,
+                        Chat, ChatInviteLink, ChatMember, ChatPermissions,
+                        File, GameHighScore, InlineKeyboardMarkup,
+                        InlineQueryResult, InputFile, InputMedia,
+                        InputMediaAudio, InputMediaDocument, InputMediaPhoto,
+                        InputMediaVideo, LabeledPrice, MaskPosition, Message,
+                        MessageEntity, MessageId, PassportElementError, Poll,
+                        ReplyMarkup, ShippingOption, StickerSet, Update, User,
                         UserProfilePhotos, WebhookInfo)
 from .constants import (ChatAction, DiceEmoji, ParseMode, PollType,
                         RequestMethod, UpdateType)
@@ -146,6 +146,7 @@ class ApiMethods(ABC):
         entities: Optional[Iterable[MessageEntity]] = None,
         disable_web_page_preview: Optional[bool] = None,
         disable_notification: Optional[bool] = None,
+        protect_content: Optional[bool] = None,
         reply_to_message_id: Optional[int] = None,
         allow_sending_without_reply: Optional[bool] = None,
         reply_markup: Optional[ReplyMarkup] = None
@@ -157,6 +158,7 @@ class ApiMethods(ABC):
             entities=_json_dumps(entities),
             disable_web_page_preview=disable_web_page_preview,
             disable_notification=disable_notification,
+            protect_content=protect_content,
             reply_to_message_id=reply_to_message_id,
             allow_sending_without_reply=allow_sending_without_reply,
             reply_markup=_json_dumps(reply_markup))
@@ -165,14 +167,16 @@ class ApiMethods(ABC):
 
     async def forward_message(
         self, chat_id: Union[int, str], from_chat_id: Union[int, str],
-        message_id: int, disable_notification: Optional[bool] = None
+        message_id: int, disable_notification: Optional[bool] = None,
+        protect_content: Optional[bool] = None,
     ) -> Message:
         api_logger.debug('Forward message %s to "%s" from "%s"', message_id,
                          chat_id, from_chat_id)
         response = await self._safe_request(
             RequestMethod.POST, 'forwardMessage', chat_id,
             from_chat_id=from_chat_id, message_id=message_id,
-            disable_notification=disable_notification)
+            disable_notification=disable_notification,
+            protect_content=protect_content)
 
         return Message.from_dict(response.result)
 
@@ -182,6 +186,7 @@ class ApiMethods(ABC):
         parse_mode: Optional[ParseMode] = None,
         caption_entities: Optional[Iterable[MessageEntity]] = None,
         disable_notification: Optional[bool] = None,
+        protect_content: Optional[bool] = None,
         reply_to_message_id: Optional[int] = None,
         allow_sending_without_reply: Optional[bool] = None,
         reply_markup: Optional[ReplyMarkup] = None
@@ -194,6 +199,7 @@ class ApiMethods(ABC):
             parse_mode=parse_mode,
             caption_entities=_json_dumps(caption_entities),
             caption=caption, disable_notification=disable_notification,
+            protect_content=protect_content,
             reply_to_message_id=reply_to_message_id,
             allow_sending_without_reply=allow_sending_without_reply,
             reply_markup=_json_dumps(reply_markup))
@@ -207,6 +213,7 @@ class ApiMethods(ABC):
         parse_mode: Optional[ParseMode] = None,
         caption_entities: Optional[Iterable[MessageEntity]] = None,
         disable_notification: Optional[bool] = None,
+        protect_content: Optional[bool] = None,
         reply_to_message_id: Optional[int] = None,
         allow_sending_without_reply: Optional[bool] = None,
         reply_markup: Optional[ReplyMarkup] = None
@@ -217,6 +224,7 @@ class ApiMethods(ABC):
             caption=caption, parse_mode=_enum_to_str(parse_mode),
             caption_entities=_json_dumps(caption_entities),
             disable_notification=disable_notification,
+            protect_content=protect_content,
             reply_to_message_id=reply_to_message_id,
             allow_sending_without_reply=allow_sending_without_reply,
             reply_markup=_json_dumps(reply_markup))
@@ -230,6 +238,7 @@ class ApiMethods(ABC):
         parse_mode: Optional[ParseMode] = None,
         caption_entities: Optional[Iterable[MessageEntity]] = None,
         disable_notification: Optional[bool] = None,
+        protect_content: Optional[bool] = None,
         duration: Optional[int] = None,
         performer: Optional[str] = None,
         title: Optional[str] = None,
@@ -244,6 +253,7 @@ class ApiMethods(ABC):
             caption=caption, parse_mode=_enum_to_str(parse_mode),
             caption_entities=_json_dumps(caption_entities),
             disable_notification=disable_notification,
+            protect_content=protect_content,
             duration=duration, performer=performer,
             title=title, thumb=thumb,
             reply_to_message_id=reply_to_message_id,
@@ -255,12 +265,13 @@ class ApiMethods(ABC):
     async def send_document(
         self, chat_id: Union[int, str],
         document: Union[InputFile, str],
-        thumb: Optional[Union[InputFile, str]],
+        thumb: Optional[Union[InputFile, str]] = None,
         caption: Optional[str] = None,
         parse_mode: Optional[ParseMode] = None,
         caption_entities: Optional[Iterable[MessageEntity]] = None,
         disable_content_type_detection: Optional[bool] = None,
         disable_notification: Optional[bool] = None,
+        protect_content: Optional[bool] = None,
         duration: Optional[int] = None,
         performer: Optional[str] = None,
         title: Optional[str] = None,
@@ -276,6 +287,7 @@ class ApiMethods(ABC):
             caption_entities=_json_dumps(caption_entities),
             disable_content_type_detection=disable_content_type_detection,
             disable_notification=disable_notification,
+            protect_content=protect_content,
             duration=duration, performer=performer, title=title,
             reply_to_message_id=reply_to_message_id,
             allow_sending_without_reply=allow_sending_without_reply,
@@ -295,6 +307,7 @@ class ApiMethods(ABC):
         caption_entities: Optional[Iterable[MessageEntity]] = None,
         supports_streaming: Optional[bool] = None,
         disable_notification: Optional[bool] = None,
+        protect_content: Optional[bool] = None,
         reply_to_message_id: Optional[int] = None,
         allow_sending_without_reply: Optional[bool] = None,
         reply_markup: Optional[ReplyMarkup] = None
@@ -308,6 +321,7 @@ class ApiMethods(ABC):
             caption_entities=_json_dumps(caption_entities),
             supports_streaming=supports_streaming,
             disable_notification=disable_notification,
+            protect_content=protect_content,
             reply_to_message_id=reply_to_message_id,
             allow_sending_without_reply=allow_sending_without_reply,
             reply_markup=_json_dumps(reply_markup))
@@ -325,6 +339,7 @@ class ApiMethods(ABC):
         parse_mode: Optional[ParseMode] = None,
         caption_entities: Optional[Iterable[MessageEntity]] = None,
         disable_notification: Optional[bool] = None,
+        protect_content: Optional[bool] = None,
         reply_to_message_id: Optional[int] = None,
         allow_sending_without_reply: Optional[bool] = None,
         reply_markup: Optional[ReplyMarkup] = None
@@ -337,6 +352,7 @@ class ApiMethods(ABC):
             parse_mode=_enum_to_str(parse_mode),
             caption_entities=_json_dumps(caption_entities),
             disable_notification=disable_notification,
+            protect_content=protect_content,
             reply_to_message_id=reply_to_message_id,
             allow_sending_without_reply=allow_sending_without_reply,
             reply_markup=_json_dumps(reply_markup))
@@ -351,6 +367,7 @@ class ApiMethods(ABC):
         caption_entities: Optional[Iterable[MessageEntity]] = None,
         duration: Optional[int] = None,
         disable_notification: Optional[bool] = None,
+        protect_content: Optional[bool] = None,
         reply_to_message_id: Optional[int] = None,
         allow_sending_without_reply: Optional[bool] = None,
         reply_markup: Optional[ReplyMarkup] = None
@@ -363,6 +380,7 @@ class ApiMethods(ABC):
             caption_entities=_json_dumps(caption_entities),
             duration=duration,
             disable_notification=disable_notification,
+            protect_content=protect_content,
             reply_to_message_id=reply_to_message_id,
             allow_sending_without_reply=allow_sending_without_reply,
             reply_markup=_json_dumps(reply_markup))
@@ -376,6 +394,7 @@ class ApiMethods(ABC):
         length: Optional[int] = None,
         thumb: Optional[Union[InputFile, str]] = None,
         disable_notification: Optional[bool] = None,
+        protect_content: Optional[bool] = None,
         reply_to_message_id: Optional[int] = None,
         allow_sending_without_reply: Optional[bool] = None,
         reply_markup: Optional[ReplyMarkup] = None
@@ -386,6 +405,7 @@ class ApiMethods(ABC):
             video_note=video_note, duration=duration,
             length=length, thumb=thumb,
             disable_notification=disable_notification,
+            protect_content=protect_content,
             reply_to_message_id=reply_to_message_id,
             allow_sending_without_reply=allow_sending_without_reply,
             reply_markup=_json_dumps(reply_markup))
@@ -397,6 +417,7 @@ class ApiMethods(ABC):
         media: Iterable[Union[InputMediaAudio, InputMediaDocument,
                               InputMediaPhoto, InputMediaVideo]],
         disable_notification: Optional[bool] = None,
+        protect_content: Optional[bool] = None,
         reply_to_message_id: Optional[int] = None,
         allow_sending_without_reply: Optional[bool] = None
     ) -> Tuple[Message, ...]:
@@ -416,6 +437,7 @@ class ApiMethods(ABC):
             RequestMethod.POST, 'sendMediaGroup', chat_id,
             media=_json_dumps(attached_media),
             disable_notification=disable_notification,
+            protect_content=protect_content,
             reply_to_message_id=reply_to_message_id,
             allow_sending_without_reply=allow_sending_without_reply,
             **attachments
@@ -433,6 +455,7 @@ class ApiMethods(ABC):
         proximity_alert_radius: Optional[int] = None,
         length: Optional[int] = None,
         disable_notification: Optional[bool] = None,
+        protect_content: Optional[bool] = None,
         reply_to_message_id: Optional[int] = None,
         allow_sending_without_reply: Optional[bool] = None,
         reply_markup: Optional[ReplyMarkup] = None
@@ -445,6 +468,7 @@ class ApiMethods(ABC):
             live_period=live_period, heading=heading,
             proximity_alert_radius=proximity_alert_radius, length=length,
             disable_notification=disable_notification,
+            protect_content=protect_content,
             reply_to_message_id=reply_to_message_id,
             allow_sending_without_reply=allow_sending_without_reply,
             reply_markup=_json_dumps(reply_markup))
@@ -505,6 +529,7 @@ class ApiMethods(ABC):
         foursquare_id: Optional[str] = None,
         foursquare_type: Optional[str] = None,
         disable_notification: Optional[bool] = None,
+        protect_content: Optional[bool] = None,
         reply_to_message_id: Optional[int] = None,
         allow_sending_without_reply: Optional[bool] = None,
         reply_markup: Optional[ReplyMarkup] = None
@@ -516,6 +541,7 @@ class ApiMethods(ABC):
             address=address, foursquare_id=foursquare_id,
             foursquare_type=foursquare_type,
             disable_notification=disable_notification,
+            protect_content=protect_content,
             reply_to_message_id=reply_to_message_id,
             allow_sending_without_reply=allow_sending_without_reply,
             reply_markup=_json_dumps(reply_markup))
@@ -529,6 +555,7 @@ class ApiMethods(ABC):
         last_name: Optional[str] = None,
         vcard: Optional[str] = None,
         disable_notification: Optional[bool] = None,
+        protect_content: Optional[bool] = None,
         reply_to_message_id: Optional[int] = None,
         allow_sending_without_reply: Optional[bool] = None,
         reply_markup: Optional[ReplyMarkup] = None
@@ -539,6 +566,7 @@ class ApiMethods(ABC):
             phone_number=phone_number, first_name=first_name,
             last_name=last_name, vcard=vcard,
             disable_notification=disable_notification,
+            protect_content=protect_content,
             reply_to_message_id=reply_to_message_id,
             allow_sending_without_reply=allow_sending_without_reply,
             reply_markup=_json_dumps(reply_markup))
@@ -558,6 +586,7 @@ class ApiMethods(ABC):
         open_period: Optional[int] = None,
         close_date: Optional[int] = None,
         disable_notification: Optional[bool] = None,
+        protect_content: Optional[bool] = None,
         reply_to_message_id: Optional[int] = None,
         allow_sending_without_reply: Optional[bool] = None,
         reply_markup: Optional[ReplyMarkup] = None
@@ -574,6 +603,7 @@ class ApiMethods(ABC):
             explanation_entities=_json_dumps(explanation_entities),
             open_period=open_period, close_date=close_date,
             disable_notification=disable_notification,
+            protect_content=protect_content,
             reply_to_message_id=reply_to_message_id,
             allow_sending_without_reply=allow_sending_without_reply,
             reply_markup=_json_dumps(reply_markup))
@@ -583,6 +613,7 @@ class ApiMethods(ABC):
     async def send_dice(self, chat_id: Union[int, str],
                         emoji: Optional[DiceEmoji] = None,
                         disable_notification: Optional[bool] = None,
+                        protect_content: Optional[bool] = None,
                         reply_to_message_id: Optional[int] = None,
                         allow_sending_without_reply: Optional[bool] = None,
                         reply_markup: Optional[ReplyMarkup] = None) -> Message:
@@ -591,6 +622,7 @@ class ApiMethods(ABC):
             RequestMethod.POST, 'sendDice', chat_id,
             emoji=_enum_to_str(emoji),
             disable_notification=disable_notification,
+            protect_content=protect_content,
             reply_to_message_id=reply_to_message_id,
             allow_sending_without_reply=allow_sending_without_reply,
             reply_markup=_json_dumps(reply_markup))
@@ -624,11 +656,11 @@ class ApiMethods(ABC):
                                        file_id=file_id)
         return File.from_dict(response.result)
 
-    async def kick_chat_member(self, chat_id: Union[int, str], user_id: int,
-                               until_date: Optional[int] = None,
-                               revoke_messages: Optional[bool] = None) -> bool:
+    async def ban_chat_member(self, chat_id: Union[int, str], user_id: int,
+                              until_date: Optional[int] = None,
+                              revoke_messages: Optional[bool] = None) -> bool:
         response = await self._request(
-            RequestMethod.POST, 'kickChatMember',
+            RequestMethod.POST, 'banChatMember',
             chat_id=chat_id, user_id=user_id, until_date=until_date,
             revoke_messages=revoke_messages)
         assert isinstance(response.result, bool)
@@ -702,6 +734,32 @@ class ApiMethods(ABC):
         assert isinstance(response.result, bool)
         return response.result
 
+    async def ban_chat_sender_chat(
+        self, chat_id: Union[int, str],
+        sender_chat_id: int,
+        until_date: Optional[int]
+    ) -> bool:
+        api_logger.debug('Ban chat "%s" sender chat "%s"',
+                         chat_id, sender_chat_id)
+        response = await self._request(
+            RequestMethod.POST, 'banChatSenderChat',
+            chat_id=chat_id, sender_chat_id=sender_chat_id,
+            until_date=until_date)
+        assert isinstance(response.result, bool)
+        return response.result
+
+    async def unban_chat_sender_chat(
+        self, chat_id: Union[int, str],
+        sender_chat_id: int
+    ) -> bool:
+        api_logger.debug('Unban chat "%s" sender chat "%s"',
+                         chat_id, sender_chat_id)
+        response = await self._request(
+            RequestMethod.POST, 'unbanChatSenderChat',
+            chat_id=chat_id, sender_chat_id=sender_chat_id)
+        assert isinstance(response.result, bool)
+        return response.result
+
     async def export_chat_invite_link(self, chat_id: Union[int, str]) -> str:
         api_logger.debug('Export chat "%s" invite link', chat_id)
         response = await self._request(
@@ -710,25 +768,31 @@ class ApiMethods(ABC):
         return response.result
 
     async def create_chat_invite_link(
-        self, chat_id: Union[int, str], expire_date: Optional[int] = None,
-        member_limit: Optional[int] = None
+        self, chat_id: Union[int, str], name: Optional[str] = None,
+        expire_date: Optional[int] = None,
+        member_limit: Optional[int] = None,
+        creates_join_request: Optional[bool] = None
     ) -> ChatInviteLink:
         api_logger.debug('Create chat "%s" invite link', chat_id)
         response = await self._request(
             RequestMethod.POST, 'createChatInviteLink', chat_id=chat_id,
-            expire_date=expire_date, member_limit=member_limit)
+            name=name, expire_date=expire_date, member_limit=member_limit,
+            creates_join_request=creates_join_request)
         return ChatInviteLink.from_dict(response.result)
 
     async def edit_chat_invite_link(
         self, chat_id: Union[int, str], invite_link: str,
+        name: Optional[str] = None,
         expire_date: Optional[int] = None,
-        member_limit: Optional[int] = None
+        member_limit: Optional[int] = None,
+        creates_join_request: Optional[bool] = None
     ) -> ChatInviteLink:
         api_logger.debug('Edit chat "%s" invite link', chat_id)
         response = await self._request(
             RequestMethod.POST, 'editChatInviteLink', chat_id=chat_id,
-            invite_link=invite_link, expire_date=expire_date,
-            member_limit=member_limit)
+            invite_link=invite_link, name=name, expire_date=expire_date,
+            member_limit=member_limit,
+            creates_join_request=creates_join_request)
         return ChatInviteLink.from_dict(response.result)
 
     async def revoke_chat_invite_link(
@@ -740,6 +804,28 @@ class ApiMethods(ABC):
             invite_link=invite_link)
         return ChatInviteLink.from_dict(response.result)
 
+    async def approve_chat_join_request(
+        self, chat_id: Union[int, str], user_id: int
+    ) -> bool:
+        api_logger.debug('Approve "%s" chat "%s" join request', chat_id,
+                         user_id)
+        response = await self._request(
+            RequestMethod.POST, 'approveChatJoinRequest', chat_id=chat_id,
+            user_id=user_id)
+        assert isinstance(response.result, bool)
+        return response.result
+
+    async def decline_chat_join_request(
+        self, chat_id: Union[int, str], user_id: int
+    ) -> bool:
+        api_logger.debug('Decline "%s" chat "%s" join request', chat_id,
+                         user_id)
+        response = await self._request(
+            RequestMethod.POST, 'declineChatJoinRequest', chat_id=chat_id,
+            user_id=user_id)
+        assert isinstance(response.result, bool)
+        return response.result
+
     async def set_chat_permissions(
         self, chat_id: Union[int, str],
         permissions: ChatPermissions
@@ -835,10 +921,10 @@ class ApiMethods(ABC):
 
         return tuple(ChatMember.from_dict(item) for item in response.result)
 
-    async def get_chat_members_count(self, chat_id: Union[int, str]) -> int:
-        api_logger.debug('Get chat members count "%s"', chat_id)
+    async def get_chat_member_count(self, chat_id: Union[int, str]) -> int:
+        api_logger.debug('Get chat member count "%s"', chat_id)
         response = await self._request(
-            RequestMethod.GET, 'getChatMembersCount', chat_id=chat_id)
+            RequestMethod.GET, 'getChatMemberCount', chat_id=chat_id)
         assert isinstance(response.result, int)
         return response.result
 
@@ -880,20 +966,39 @@ class ApiMethods(ABC):
         assert isinstance(response.result, bool)
         return response.result
 
-    async def set_my_commands(self, commands: Iterable[BotCommand]) -> bool:
+    async def set_my_commands(self, commands: Iterable[BotCommand],
+                              scope: Optional[BotCommandScope] = None,
+                              language_code: Optional[str] = None) -> bool:
         api_logger.debug('Set my commands "%s"', commands)
         response = await self._request(
             RequestMethod.POST, 'setMyCommands',
-            commands=_json_dumps(commands))
+            commands=_json_dumps(commands), scope=_json_dumps(scope),
+            language_code=language_code)
         assert isinstance(response.result, bool)
         return response.result
 
-    async def get_my_commands(self) -> Tuple[BotCommand, ...]:
+    async def get_my_commands(
+        self, scope: Optional[BotCommandScope] = None,
+        language_code: Optional[str] = None
+    ) -> Tuple[BotCommand, ...]:
         api_logger.debug('Get my commands')
-        response = await self._request(RequestMethod.GET, 'getMyCommands')
+        response = await self._request(
+            RequestMethod.GET, 'getMyCommands', scope=_json_dumps(scope),
+            language_code=language_code)
 
         return tuple(BotCommand.from_dict(item) for item in response.result)
 
+    async def delete_my_commands(
+        self, scope: Optional[BotCommandScope] = None,
+        language_code: Optional[str] = None
+    ) -> bool:
+        api_logger.debug('Delete my commands')
+        response = await self._request(
+            RequestMethod.GET, 'deleteMyCommands', scope=_json_dumps(scope),
+            language_code=language_code)
+        assert isinstance(response.result, bool)
+        return response.result
+
     async def edit_message_text(
         self,
         text: str,
@@ -1053,6 +1158,7 @@ class ApiMethods(ABC):
         self, chat_id: Union[int, str],
         sticker: Union[InputFile, str],
         disable_notification: Optional[bool] = None,
+        protect_content: Optional[bool] = None,
         reply_to_message_id: Optional[int] = None,
         allow_sending_without_reply: Optional[bool] = None,
         reply_markup: Optional[ReplyMarkup] = None
@@ -1062,6 +1168,7 @@ class ApiMethods(ABC):
             RequestMethod.POST, 'sendSticker',
             chat_id=chat_id, sticker=sticker,
             disable_notification=disable_notification,
+            protect_content=protect_content,
             reply_to_message_id=reply_to_message_id,
             allow_sending_without_reply=allow_sending_without_reply,
             reply_markup=_json_dumps(reply_markup))
@@ -1088,6 +1195,7 @@ class ApiMethods(ABC):
         self, user_id: int, name: str, title: str, emojis: str,
         png_sticker: Union[InputFile, str, None] = None,
         tgs_sticker: Optional[InputFile] = None,
+        webm_sticker: Optional[InputFile] = None,
         contains_masks: Optional[bool] = None,
         mask_position: Optional[MaskPosition] = None
     ) -> bool:
@@ -1096,21 +1204,25 @@ class ApiMethods(ABC):
             RequestMethod.POST, 'createNewStickerSet',
             user_id=user_id, name=name, title=title, emojis=emojis,
             png_sticker=png_sticker, tgs_sticker=tgs_sticker,
-            contains_masks=contains_masks,
+            webm_sticker=webm_sticker, contains_masks=contains_masks,
             mask_position=_json_dumps(mask_position))
         assert isinstance(response.result, bool)
         return response.result
 
     async def add_sticker_to_set(
-        self, user_id: int, name: str, title: str,
-        png_sticker: Union[InputFile, str], emojis: str,
+        self, user_id: int, name: str, title: str, emojis: str,
+        png_sticker: Union[InputFile, str],
+        tgs_sticker: Optional[InputFile] = None,
+        webm_sticker: Optional[InputFile] = None,
         mask_position: Optional[MaskPosition] = None
     ) -> File:
         api_logger.debug('Add sticker to set "%s" for %s', name, user_id)
         response = await self._request(
             RequestMethod.POST, 'addStickerToSet',
-            user_id=user_id, name=name, title=title, png_sticker=png_sticker,
-            emojis=emojis, mask_position=_json_dumps(mask_position))
+            user_id=user_id, name=name, title=title, emojis=emojis,
+            png_sticker=png_sticker, tgs_sticker=tgs_sticker,
+            webm_sticker=webm_sticker,
+            mask_position=_json_dumps(mask_position))
 
         return File.from_dict(response.result)
 
@@ -1177,6 +1289,7 @@ class ApiMethods(ABC):
         send_email_to_provider: Optional[bool] = None,
         is_flexible: Optional[bool] = None,
         disable_notification: Optional[bool] = None,
+        protect_content: Optional[bool] = None,
         reply_to_message_id: Optional[int] = None,
         allow_sending_without_reply: Optional[bool] = None,
         reply_markup: Optional[InlineKeyboardMarkup] = None
@@ -1200,6 +1313,7 @@ class ApiMethods(ABC):
             send_email_to_provider=send_email_to_provider,
             is_flexible=is_flexible,
             disable_notification=disable_notification,
+            protect_content=protect_content,
             reply_to_message_id=reply_to_message_id,
             allow_sending_without_reply=allow_sending_without_reply,
             reply_markup=_json_dumps(reply_markup))
@@ -1248,6 +1362,7 @@ class ApiMethods(ABC):
     async def send_game(
         self, chat_id: int, game_short_name: str,
         disable_notification: Optional[bool] = None,
+        protect_content: Optional[bool] = None,
         reply_to_message_id: Optional[int] = None,
         allow_sending_without_reply: Optional[bool] = None,
         reply_markup: Optional[InlineKeyboardMarkup] = None
@@ -1257,6 +1372,7 @@ class ApiMethods(ABC):
             RequestMethod.POST, 'sendGame', chat_id,
             game_short_name=game_short_name,
             disable_notification=disable_notification,
+            protect_content=protect_content,
             reply_to_message_id=reply_to_message_id,
             allow_sending_without_reply=allow_sending_without_reply,
             reply_markup=_json_dumps(reply_markup))
