@@ -207,13 +207,13 @@ class Bot(MutableMapping[str, Any], ApiMethods):
         chat = await self.get_chat(chat_id)
         while True:
             try:
-                message_limit = self._message_limit.acquire()
+                message_limit = self._message_limit.resource()
                 if chat.type in (ChatType.GROUP, ChatType.SUPERGROUP):
-                    group_limit = self._group_limit.acquire(chat.id)
+                    group_limit = self._group_limit.resource(chat.id)
                     async with message_limit, group_limit:
                         return await request()
                 else:
-                    chat_limit = self._chat_limit.acquire(chat.id)
+                    chat_limit = self._chat_limit.resource(chat.id)
                     async with message_limit, chat_limit:
                         return await request()
             except RetryAfter as retry_after:
@@ -285,7 +285,7 @@ class Bot(MutableMapping[str, Any], ApiMethods):
         update_state = self._update_state(update)
         state_key = f'{STATE_PREFIX}|{update_state}'
         context_key = f'{CONTEXT_PREFIX}|{update_state}'
-        async with self._context_lock.acquire(state_key):
+        async with self._context_lock.resource(state_key):
             state = await self._storage.get(state_key)
             assert isinstance(state, str) or state is None
             context_dict = await self._storage.get(context_key)
