@@ -2,12 +2,17 @@ from abc import abstractmethod
 from typing import (Any, AsyncIterator, Dict, List, Protocol, Tuple, Union,
                     runtime_checkable)
 
+__all__ = ('Json', 'StorageProtocol')
+
 Json = Union[str, int, float, bool, Dict[str, Any], List[Any], None]
 
 
 @runtime_checkable
 class StorageProtocol(Protocol):
 
+    @abstractmethod
+    async def connect(self) -> None: ...
+
     @abstractmethod
     async def close(self) -> None: ...
 
@@ -25,3 +30,6 @@ class StorageProtocol(Protocol):
 
     @abstractmethod
     async def clear(self) -> None: ...
+
+    @abstractmethod
+    def raw_connection(self) -> Any: ...
