@@ -2,12 +2,16 @@ from typing import Any, AsyncIterator, Dict, Final, Tuple
 
 from aiotgbot.storage import Json, StorageProtocol
 
+__all__ = ('MemoryStorage',)
+
 
 class MemoryStorage(StorageProtocol):
 
     def __init__(self) -> None:
         self._data: Final[Dict[str, Any]] = {}
 
+    async def connect(self) -> None: ...
+
     async def close(self) -> None: ...
 
     async def set(self, key: str, value: Json = None) -> None:
@@ -28,3 +32,6 @@ class MemoryStorage(StorageProtocol):
 
     async def clear(self) -> None:
         self._data.clear()
+
+    def raw_connection(self) -> Any:
+        return None
